@@ -7,7 +7,7 @@ use Alien::Build;
 use base qw( Module::Build );
 
 # ABSTRACT: Alien::Build installer class for Module::Build
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 sub new
@@ -165,6 +165,12 @@ sub ACTION_alien_build
       "require ${package};\n",
       "sub Inline { shift; ${package}->Inline(\@_) }\n",
       "1;\n",
+      "\n",
+      "=begin Pod::Coverage\n",
+      "\n",
+      "  Inline\n",
+      "\n",
+      "=cut\n",
     );
   };
 
@@ -217,7 +223,7 @@ Alien::Build::MB - Alien::Build installer class for Module::Build
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -302,7 +308,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
